
#property strict
#property indicator_chart_window
#property indicator_buffers 3
#property indicator_label1  "Super Trend"
#property indicator_type1   DRAW_LINE
#property indicator_color1  clrBlue
#property indicator_width1  2
#property indicator_label2  "Super Trend"
#property indicator_type2   DRAW_LINE
#property indicator_color2  clrRed
#property indicator_width2  2
#property indicator_label3  "Super Trend"
#property indicator_type3   DRAW_LINE
#property indicator_color3  clrRed
#property indicator_width3  2

//
//
//

input int                inpPeriod       = 50;            // Cci Period
input ENUM_APPLIED_PRICE inpPrice        = PRICE_TYPICAL; // Cci Price
input int                inpAtrPeriod    = 5;             // Atr period
input bool               alertsOn        = true;          // Alerts on true/false?
input bool               alertsOnCurrent = false;         // Alerts on open bar true/false?
input bool               alertsMessage   = true;          // Alerts pop-up message true/false?
input bool               alertsSound     = false;         // Alerts sound true/false?
input bool               alertsNotify    = false;         // Alerts push notification true/false?
input bool               alertsEmail     = false;         // Alerts email true/false?
input string             soundFile       = "alert2.wav";  // Sound file

double val[],valda[],valdb[],trend[],valc[];

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//

int OnInit()
{
   IndicatorBuffers(5);
   SetIndexBuffer(0,val  ,INDICATOR_DATA);
   SetIndexBuffer(1,valda,INDICATOR_DATA);
   SetIndexBuffer(2,valdb,INDICATOR_DATA);
   SetIndexBuffer(3,trend);
   SetIndexBuffer(4,valc);

   IndicatorSetString(INDICATOR_SHORTNAME,"SuperTrend");
return (INIT_SUCCEEDED);
}
void OnDeinit(const int reason) { }

//
//
//

int  OnCalculate(const int rates_total,const int prev_calculated,const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
{
   int i=rates_total-prev_calculated+1; if (i>=rates_total) i=rates_total-1;

   //
   //
   //
   
   if (valc[i]==-1) iCleanPoint(i,valda,valdb);
   for (; i>=0 && !_StopFlag; i--)
   {
      double cci = iCCI(NULL,0,inpPeriod,inpPrice,i);
      double atr = iATR(NULL,0,inpAtrPeriod,i);
      trend[i] = (cci>0) ? 1 : (cci<0) ? -1 : (i<rates_total-1) ? trend[i+1] : 0;
      val[i]   = (i<rates_total-1) ? (trend[i]==1) ? fmax(low[i]-atr,val[i+1]) : fmin(high[i]+atr,val[i+1]) : close[i];
      valc[i]  = (i<rates_total-1) ? (val[i]>val[i+1]) ? 1 :(val[i]<val[i+1]) ? -1 : valc[i+1]: 0; 
      valda[i] = valdb[i] = EMPTY_VALUE;  if (valc[i] == -1) iPlotPoint(i,valda,valdb,val);
   }
   if (alertsOn)
   {
      int whichBar = (alertsOnCurrent) ? 0 : 1;
      if (valc[whichBar] != valc[whichBar+1])
      {
         if (valc[whichBar] == 1) doAlert(" up");
         if (valc[whichBar] ==-1) doAlert(" down");       
      }         
   }        
return(rates_total);
}

//
//
//

void iCleanPoint(int i,double& first[],double& second[])
{
   if (i>=Bars-3) return;
   if ((second[i]  != EMPTY_VALUE) && (second[i+1] != EMPTY_VALUE))
        second[i+1] = EMPTY_VALUE;
   else
      if ((first[i] != EMPTY_VALUE) && (first[i+1] != EMPTY_VALUE) && (first[i+2] == EMPTY_VALUE))
          first[i+1] = EMPTY_VALUE;
}
void iPlotPoint(int i,double& first[],double& second[],double& from[])
{
   if (i>=Bars-2) return;
   if (first[i+1] == EMPTY_VALUE)
      if (first[i+2] == EMPTY_VALUE)
            { first[i]  = from[i];  first[i+1]  = from[i+1]; second[i] = EMPTY_VALUE; }
      else  { second[i] =  from[i]; second[i+1] = from[i+1]; first[i]  = EMPTY_VALUE; }
   else     { first[i]  = from[i];                           second[i] = EMPTY_VALUE; }
}

//------------------------------------------------------------------
//
//------------------------------------------------------------------

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message = timeFrameToString(_Period)+" "+_Symbol+" at "+TimeToStr(TimeLocal(),TIME_SECONDS)+" SuperTrend "+doWhat;
             if (alertsMessage)  Alert(message);
             if (alertsNotify)   SendNotification(message);
             if (alertsEmail)    SendMail(_Symbol+" SuperTrend ",message);
             if (alertsSound)    PlaySound(soundFile);
      }
}

//-------------------------------------------------------------------
//                                                                  
//-------------------------------------------------------------------

string sTfTable[] = {"M1","M5","M15","M30","H1","H4","D1","W1","MN"};
int    iTfTable[] = {1,5,15,30,60,240,1440,10080,43200};

string timeFrameToString(int tf)
{
   for (int i=ArraySize(iTfTable)-1; i>=0; i--) 
         if (tf==iTfTable[i]) return(sTfTable[i]);
                              return("");
}


